<?php

use App\Http\Controllers\FrontController;
use App\Http\Controllers\LoginController;
use App\Http\Controllers\PostController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\UserController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', [FrontController::class , 'index'])->name('front');

//Login route
Route::get('/admin/login',[LoginController::class,'index'])->name('admin.connection');
Route::post('/admin/connection/perform',[LoginController::class,'login'])->name('admin.connection.perform');
Route::get('/erreur', function () {
    return view('admin.pages.erreur.LoginErreur');
})->name('admin.erreur');


Route::name('admin.')->middleware('CheckAdminMiddleware')->group( function () {

    Route::group(['prefix' => 'admin'], function () {


        Route::get('/dashboard', function () {
            return view('admin.dashboard');
        })->name('dashboard');
        //Post route
        Route::get('/posts',[PostController::class , 'index'])->name('post');
        Route::post('/add-post',[PostController::class , 'addPost'])->name('add.post');
        Route::get('/post-show/{id}' , [PostController::class , 'show'])->name('show.post');
        Route::get('/delete-post/{id}' , [PostController::class , 'delete'])->name('delete.post');
        Route::get('/post-liste' , [PostController::class , 'liste'])->name('liste.post');
        //Product route
        Route::get('/products',[ProductController::class,'index'])->name('product');
        Route::post('/add-products',[ProductController::class,'addProduct'])->name('add.product');
        Route::get('/product-show/{id}' , [ProductController::class , 'show'])->name('show.product');
        Route::get('/delete-product/{id}' , [ProductController::class , 'delete'])->name('delete.product');
        Route::get('/product-liste' , [ProductController::class,'liste'])->name('liste.product');
        //Role route
        Route::get('/roles',[RoleController::class,'index'])->name('role');
        Route::post('/roles-add',[RoleController::class,'addRole'])->name('add.role');
        Route::get('/roles-show/{id}',[RoleController::class,'show'])->name('show.role');
        Route::get('/role-delete/{id}',[RoleController::class,'delete'])->name('delete.role');

        Route::get('/admin/deconnection',[LoginController::class,'logout'])->name('deconnection');
        Route::get('/admin/utilisateur',[UserController::class,'index'])->name('utilisateur');
        Route::post('/admin/utilisateur/perform',[UserController::class,'addUser'])->name('utilisateur.perform');
        Route::get('/admin/utilisateur/delete/{id}',[UserController::class,'delete'])->name('utilisateur.delete');
        Route::get('/admin/utilisateur/show/{id}',[UserController::class,'show'])->name('utilisateur.show');
        //Videos route
        Route::get('/videos',[ProductController::class,'index'])->name('video');
        Route::post('/add-videos',[ProductController::class,'addProduct'])->name('add.video');
        Route::get('/video-show/{id}' , [ProductController::class , 'show'])->name('show.video');
        Route::get('/delete-video/{id}' , [ProductController::class , 'delete'])->name('delete.video');
        Route::get('/videos-liste' , [ProductController::class,'liste'])->name('liste.video');
    });


});
